@@ -6,7 +6,7 @@
 
 #include "spvm_memory_pool.h"
 #include "spvm_util_allocator.h"
-#include "spvm_value.h"
+#include "spvm_api.h"
 
 SPVM_MEMORY_POOL* SPVM_MEMORY_POOL_new(int32_t page_byte_size) {
   
@@ -41,7 +41,7 @@ void* SPVM_MEMORY_POOL_alloc(SPVM_MEMORY_POOL* memory_pool, int32_t byte_size) {
   }
   
   // Adjust alignment
-  int32_t aligned_byte_size = (byte_size - 1) + ((int32_t)sizeof(SPVM_VALUE) - ((byte_size - 1) % (int32_t)sizeof(SPVM_VALUE)));
+  int32_t aligned_byte_size = (byte_size - 1) + ((int32_t)sizeof(SPVM_API_VALUE) - ((byte_size - 1) % (int32_t)sizeof(SPVM_API_VALUE)));
   
   // Move to next page
   if (memory_pool->current_offset + aligned_byte_size > memory_pool->page_byte_size) {
